==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkForceDirectedLayoutStrategy.java <==
// java wrapper for vtkForceDirectedLayoutStrategy object
//

package vtk;
import vtk.*;

public class vtkForceDirectedLayoutStrategy extends vtkGraphLayoutStrategy
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRandomSeed_2(int id0);
  public void SetRandomSeed(int id0)
    { SetRandomSeed_2(id0); }

  private native int GetRandomSeedMinValue_3();
  public int GetRandomSeedMinValue()
    { return GetRandomSeedMinValue_3(); }

  private native int GetRandomSeedMaxValue_4();
  public int GetRandomSeedMaxValue()
    { return GetRandomSeedMaxValue_4(); }

  private native int GetRandomSeed_5();
  public int GetRandomSeed()
    { return GetRandomSeed_5(); }

  private native void SetGraphBounds_6(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetGraphBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetGraphBounds_6(id0,id1,id2,id3,id4,id5); }

  private native void SetGraphBounds_7(double id0[]);
  public void SetGraphBounds(double id0[])
    { SetGraphBounds_7(id0); }

  private native double[] GetGraphBounds_8();
  public double[] GetGraphBounds()
    { return GetGraphBounds_8(); }

  private native void SetAutomaticBoundsComputation_9(int id0);
  public void SetAutomaticBoundsComputation(int id0)
    { SetAutomaticBoundsComputation_9(id0); }

  private native int GetAutomaticBoundsComputation_10();
  public int GetAutomaticBoundsComputation()
    { return GetAutomaticBoundsComputation_10(); }

  private native void AutomaticBoundsComputationOn_11();
  public void AutomaticBoundsComputationOn()
    { AutomaticBoundsComputationOn_11(); }

  private native void AutomaticBoundsComputationOff_12();
  public void AutomaticBoundsComputationOff()
    { AutomaticBoundsComputationOff_12(); }

  private native void SetMaxNumberOfIterations_13(int id0);
  public void SetMaxNumberOfIterations(int id0)
    { SetMaxNumberOfIterations_13(id0); }

  private native int GetMaxNumberOfIterationsMinValue_14();
  public int GetMaxNumberOfIterationsMinValue()
    { return GetMaxNumberOfIterationsMinValue_14(); }

  private native int GetMaxNumberOfIterationsMaxValue_15();
  public int GetMaxNumberOfIterationsMaxValue()
    { return GetMaxNumberOfIterationsMaxValue_15(); }

  private native int GetMaxNumberOfIterations_16();
  public int GetMaxNumberOfIterations()
    { return GetMaxNumberOfIterations_16(); }

  private native void SetIterationsPerLayout_17(int id0);
  public void SetIterationsPerLayout(int id0)
    { SetIterationsPerLayout_17(id0); }

  private native int GetIterationsPerLayoutMinValue_18();
  public int GetIterationsPerLayoutMinValue()
    { return GetIterationsPerLayoutMinValue_18(); }

  private native int GetIterationsPerLayoutMaxValue_19();
  public int GetIterationsPerLayoutMaxValue()
    { return GetIterationsPerLayoutMaxValue_19(); }

  private native int GetIterationsPerLayout_20();
  public int GetIterationsPerLayout()
    { return GetIterationsPerLayout_20(); }

  private native void SetCoolDownRate_21(double id0);
  public void SetCoolDownRate(double id0)
    { SetCoolDownRate_21(id0); }

  private native double GetCoolDownRateMinValue_22();
  public double GetCoolDownRateMinValue()
    { return GetCoolDownRateMinValue_22(); }

  private native double GetCoolDownRateMaxValue_23();
  public double GetCoolDownRateMaxValue()
    { return GetCoolDownRateMaxValue_23(); }

  private native double GetCoolDownRate_24();
  public double GetCoolDownRate()
    { return GetCoolDownRate_24(); }

  private native void SetThreeDimensionalLayout_25(int id0);
  public void SetThreeDimensionalLayout(int id0)
    { SetThreeDimensionalLayout_25(id0); }

  private native int GetThreeDimensionalLayout_26();
  public int GetThreeDimensionalLayout()
    { return GetThreeDimensionalLayout_26(); }

  private native void ThreeDimensionalLayoutOn_27();
  public void ThreeDimensionalLayoutOn()
    { ThreeDimensionalLayoutOn_27(); }

  private native void ThreeDimensionalLayoutOff_28();
  public void ThreeDimensionalLayoutOff()
    { ThreeDimensionalLayoutOff_28(); }

  private native void SetRandomInitialPoints_29(int id0);
  public void SetRandomInitialPoints(int id0)
    { SetRandomInitialPoints_29(id0); }

  private native int GetRandomInitialPoints_30();
  public int GetRandomInitialPoints()
    { return GetRandomInitialPoints_30(); }

  private native void RandomInitialPointsOn_31();
  public void RandomInitialPointsOn()
    { RandomInitialPointsOn_31(); }

  private native void RandomInitialPointsOff_32();
  public void RandomInitialPointsOff()
    { RandomInitialPointsOff_32(); }

  private native void SetInitialTemperature_33(double id0);
  public void SetInitialTemperature(double id0)
    { SetInitialTemperature_33(id0); }

  private native double GetInitialTemperatureMinValue_34();
  public double GetInitialTemperatureMinValue()
    { return GetInitialTemperatureMinValue_34(); }

  private native double GetInitialTemperatureMaxValue_35();
  public double GetInitialTemperatureMaxValue()
    { return GetInitialTemperatureMaxValue_35(); }

  private native double GetInitialTemperature_36();
  public double GetInitialTemperature()
    { return GetInitialTemperature_36(); }

  private native void Initialize_37();
  public void Initialize()
    { Initialize_37(); }

  private native void Layout_38();
  public void Layout()
    { Layout_38(); }

  private native int IsLayoutComplete_39();
  public int IsLayoutComplete()
    { return IsLayoutComplete_39(); }

  public vtkForceDirectedLayoutStrategy() { super(); }

  public vtkForceDirectedLayoutStrategy(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-aarch64.pkg.tar.xz: vtk/vtkForceDirectedLayoutStrategy.java <==
// java wrapper for vtkForceDirectedLayoutStrategy object
//

package vtk;
import vtk.*;

public class vtkForceDirectedLayoutStrategy extends vtkGraphLayoutStrategy
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRandomSeed_2(int id0);
  public void SetRandomSeed(int id0)
    { SetRandomSeed_2(id0); }

  private native int GetRandomSeedMinValue_3();
  public int GetRandomSeedMinValue()
    { return GetRandomSeedMinValue_3(); }

  private native int GetRandomSeedMaxValue_4();
  public int GetRandomSeedMaxValue()
    { return GetRandomSeedMaxValue_4(); }

  private native int GetRandomSeed_5();
  public int GetRandomSeed()
    { return GetRandomSeed_5(); }

  private native void SetGraphBounds_6(double id0,double id1,double id2,double id3,double id4,double id5);
  public void SetGraphBounds(double id0,double id1,double id2,double id3,double id4,double id5)
    { SetGraphBounds_6(id0,id1,id2,id3,id4,id5); }

  private native void SetGraphBounds_7(double id0[]);
  public void SetGraphBounds(double id0[])
    { SetGraphBounds_7(id0); }

  private native double[] GetGraphBounds_8();
  public double[] GetGraphBounds()
    { return GetGraphBounds_8(); }

  private native void SetAutomaticBoundsComputation_9(int id0);
  public void SetAutomaticBoundsComputation(int id0)
    { SetAutomaticBoundsComputation_9(id0); }

  private native int GetAutomaticBoundsComputation_10();
  public int GetAutomaticBoundsComputation()
    { return GetAutomaticBoundsComputation_10(); }

  private native void AutomaticBoundsComputationOn_11();
  public void AutomaticBoundsComputationOn()
    { AutomaticBoundsComputationOn_11(); }

  private native void AutomaticBoundsComputationOff_12();
  public void AutomaticBoundsComputationOff()
    { AutomaticBoundsComputationOff_12(); }

  private native void SetMaxNumberOfIterations_13(int id0);
  public void SetMaxNumberOfIterations(int id0)
    { SetMaxNumberOfIterations_13(id0); }

  private native int GetMaxNumberOfIterationsMinValue_14();
  public int GetMaxNumberOfIterationsMinValue()
    { return GetMaxNumberOfIterationsMinValue_14(); }

  private native int GetMaxNumberOfIterationsMaxValue_15();
  public int GetMaxNumberOfIterationsMaxValue()
    { return GetMaxNumberOfIterationsMaxValue_15(); }

  private native int GetMaxNumberOfIterations_16();
  public int GetMaxNumberOfIterations()
    { return GetMaxNumberOfIterations_16(); }

  private native void SetIterationsPerLayout_17(int id0);
  public void SetIterationsPerLayout(int id0)
    { SetIterationsPerLayout_17(id0); }

  private native int GetIterationsPerLayoutMinValue_18();
  public int GetIterationsPerLayoutMinValue()
    { return GetIterationsPerLayoutMinValue_18(); }

  private native int GetIterationsPerLayoutMaxValue_19();
  public int GetIterationsPerLayoutMaxValue()
    { return GetIterationsPerLayoutMaxValue_19(); }

  private native int GetIterationsPerLayout_20();
  public int GetIterationsPerLayout()
    { return GetIterationsPerLayout_20(); }

  private native void SetCoolDownRate_21(double id0);
  public void SetCoolDownRate(double id0)
    { SetCoolDownRate_21(id0); }

  private native double GetCoolDownRateMinValue_22();
  public double GetCoolDownRateMinValue()
    { return GetCoolDownRateMinValue_22(); }

  private native double GetCoolDownRateMaxValue_23();
  public double GetCoolDownRateMaxValue()
    { return GetCoolDownRateMaxValue_23(); }

  private native double GetCoolDownRate_24();
  public double GetCoolDownRate()
    { return GetCoolDownRate_24(); }

  private native void SetThreeDimensionalLayout_25(int id0);
  public void SetThreeDimensionalLayout(int id0)
    { SetThreeDimensionalLayout_25(id0); }

  private native int GetThreeDimensionalLayout_26();
  public int GetThreeDimensionalLayout()
    { return GetThreeDimensionalLayout_26(); }

  private native void ThreeDimensionalLayoutOn_27();
  public void ThreeDimensionalLayoutOn()
    { ThreeDimensionalLayoutOn_27(); }

  private native void ThreeDimensionalLayoutOff_28();
  public void ThreeDimensionalLayoutOff()
    { ThreeDimensionalLayoutOff_28(); }

  private native void SetRandomInitialPoints_29(int id0);
  public void SetRandomInitialPoints(int id0)
    { SetRandomInitialPoints_29(id0); }

  private native int GetRandomInitialPoints_30();
  public int GetRandomInitialPoints()
    { return GetRandomInitialPoints_30(); }

  private native void RandomInitialPointsOn_31();
  public void RandomInitialPointsOn()
    { RandomInitialPointsOn_31(); }

  private native void RandomInitialPointsOff_32();
  public void RandomInitialPointsOff()
    { RandomInitialPointsOff_32(); }

  private native void SetInitialTemperature_33(double id0);
  public void SetInitialTemperature(double id0)
    { SetInitialTemperature_33(id0); }

  private native double GetInitialTemperatureMinValue_34();
  public double GetInitialTemperatureMinValue()
    { return GetInitialTemperatureMinValue_34(); }

  private native double GetInitialTemperatureMaxValue_35();
  public double GetInitialTemperatureMaxValue()
    { return GetInitialTemperatureMaxValue_35(); }

  private native double GetInitialTemperature_36();
  public double GetInitialTemperature()
    { return GetInitialTemperature_36(); }

  private native void Initialize_37();
  public void Initialize()
    { Initialize_37(); }

  private native void Layout_38();
  public void Layout()
    { Layout_38(); }

  private native int IsLayoutComplete_39();
  public int IsLayoutComplete()
    { return IsLayoutComplete_39(); }

  public vtkForceDirectedLayoutStrategy() { super(); }

  public vtkForceDirectedLayoutStrategy(long id) { super(id); }
  public native long   VTKInit();

}
